@@ -54,6 +54,7 @@ def ForeignKey(
 
 class ForeignKeyField(BaseField):
     to: Type["Model"]
+    name: str
     related_name: str
     virtual: bool
 
@@ -65,36 +66,35 @@ class ForeignKeyField(BaseField):
     def validate(cls, value: Any) -> Any:
         return value
 
-    # @property
-    # def __type__(self) -> Type[BaseModel]:
-    #     return self.to.__pydantic_model__
-
-    # @classmethod
-    # def get_column_type(cls) -> sqlalchemy.Column:
-    #     to_column = cls.to.Meta.model_fields[cls.to.Meta.pkname]
-    #     return to_column.column_type
-
     @classmethod
     def _extract_model_from_sequence(
-        cls, value: List, child: "Model"
+        cls, value: List, child: "Model", to_register: bool
     ) -> Union["Model", List["Model"]]:
-        return [cls.expand_relationship(val, child) for val in value]
+        return [cls.expand_relationship(val, child, to_register) for val in value]
 
     @classmethod
-    def _register_existing_model(cls, value: "Model", child: "Model") -> "Model":
-        cls.register_relation(value, child)
+    def _register_existing_model(
+        cls, value: "Model", child: "Model", to_register: bool
+    ) -> "Model":
+        if to_register:
+            cls.register_relation(value, child)
         return value
 
     @classmethod
-    def _construct_model_from_dict(cls, value: dict, child: "Model") -> "Model":
+    def _construct_model_from_dict(
+        cls, value: dict, child: "Model", to_register: bool
+    ) -> "Model":
         if len(value.keys()) == 1 and list(value.keys())[0] == cls.to.Meta.pkname:
             value["__pk_only__"] = True
         model = cls.to(**value)
-        cls.register_relation(model, child)
+        if to_register:
+            cls.register_relation(model, child)
         return model
 
     @classmethod
-    def _construct_model_from_pk(cls, value: Any, child: "Model") -> "Model":
+    def _construct_model_from_pk(
+        cls, value: Any, child: "Model", to_register: bool
+    ) -> "Model":
         if not isinstance(value, cls.to.pk_type()):
             raise RelationshipInstanceError(
                 f"Relationship error - ForeignKey {cls.to.__name__} "
@@ -102,19 +102,19 @@ class ForeignKeyField(BaseField):
                 f"while {type(value)} passed as a parameter."
             )
         model = create_dummy_instance(fk=cls.to, pk=value)
-        cls.register_relation(model, child)
+        if to_register:
+            cls.register_relation(model, child)
         return model
 
     @classmethod
     def register_relation(cls, model: "Model", child: "Model") -> None:
-        child_model_name = cls.related_name or child.get_name()
-        model.Meta._orm_relationship_manager.add_relation(
-            model, child, child_model_name, virtual=cls.virtual
+        model._orm.add(
+            parent=model, child=child, child_name=cls.related_name, virtual=cls.virtual
         )
 
     @classmethod
     def expand_relationship(
-        cls, value: Any, child: "Model"
+        cls, value: Any, child: "Model", to_register: bool = True
     ) -> Optional[Union["Model", List["Model"]]]:
         if value is None:
             return None
@@ -127,5 +127,5 @@ class ForeignKeyField(BaseField):
 
         model = constructors.get(
             value.__class__.__name__, cls._construct_model_from_pk
-        )(value, child)
+        )(value, child, to_register)
         return model
